package org.colinvella.fancyfish.entity.ai;

import org.colinvella.fancyfish.FancyFishMod;
import org.colinvella.fancyfish.entity.fish.FishEntity;
import org.colinvella.fancyfish.logger.ModLogger;

import net.minecraft.block.Block;
import net.minecraft.entity.ai.EntityAIBase;
import net.minecraft.init.Blocks;
import net.minecraft.util.BlockPos;
import net.minecraft.util.MathHelper;
import net.minecraft.util.Vec3;
import net.minecraft.world.World;

public class FishEntityAISwimAround extends EntityAIBase
{   
    public FishEntityAISwimAround(FishEntity fishEntity)
    {
    	if (logger == null)
    		logger = FancyFishMod.getLogger();
    		
    	this.fishEntity = fishEntity;
    	this.swimmingSpeed = fishEntity.getSwimmingSpeed();
    	
    	this.setMutexBits(1);
    }
    
    @Override
    public boolean shouldExecute()
    {
        return this.fishEntity.isInWater();
    }

    @Override
    public void updateTask()
    {         
    	// set new target motion on 1/50 chance of if target motion is zero
        if (this.fishEntity.getRNG().nextInt(50) == 0 || !this.fishEntity.hasTargetMotion())
        {
        	// chose random angle in XZ plane
            float angle = this.fishEntity.getRNG().nextFloat() * (float)Math.PI * 2.0F;
            
            double targetMotionX = MathHelper.cos(angle) * swimmingSpeed;
            double targetMotionZ = MathHelper.sin(angle) * swimmingSpeed;

            double targetMotionY = (this.fishEntity.getRNG().nextDouble() * 2.0 - 1.0) * swimmingSpeed;

            this.fishEntity.setTargetMotion(targetMotionX, targetMotionY, targetMotionZ);
        }
        
        // if breached surface, dip down
        World world = this.fishEntity.worldObj;
        Vec3 entityPositionAbove = this.fishEntity.getPositionVector();
        entityPositionAbove = entityPositionAbove.add(new Vec3(0, 0.25, 0));
        
        if (!this.fishEntity.isInWater())
        {
        	this.fishEntity.setTargetMotion(0f, -swimmingSpeed, 0f);
        }
    }
    
    private FishEntity fishEntity;
    private double swimmingSpeed;
    
    private static ModLogger logger;
}	