package org.colinvella.fancyfish.entity.model;

import org.colinvella.fancyfish.entity.fish.FishEntity;

import net.minecraft.client.model.ModelBase;
import net.minecraft.client.model.ModelRenderer;
import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.entity.Entity;

public class FishModel extends ModelBase
{
	public FishModel()
	{
	    textureWidth = 16;
	    textureHeight = 16;
	    
	    body = new ModelRenderer(this, 0, 0);
	    body.addBox(-0.5F, -1.5F, -2.5f, 1, 3, 5);
	    body.setRotationPoint(0F, 21.5F, 0F);
	    body.setTextureSize(textureWidth, textureHeight);
	    body.mirror = true;
	    setRotation(body, 0F, 0F, 0F);
	    
	    dorsalFin = new ModelRenderer(this, 0, 1);
	    dorsalFin.addBox(0F, -1F, -1F, 0, 1, 2);
	    dorsalFin.setRotationPoint(0F, 20F, 0F);
	    dorsalFin.setTextureSize(16, 16);
	    dorsalFin.mirror = true;
	    setRotation(dorsalFin, 0F, 0F, 0F);
	    
	    leftFin = new ModelRenderer(this, 0, 0);
	    leftFin.addBox(0F, 0F, -0.5F, 0, 1, 1);
	    leftFin.setRotationPoint(0.5F, 23F, 0F);
	    leftFin.setTextureSize(textureWidth, textureHeight);
	    leftFin.mirror = true;
	    setRotation(leftFin, 0F, 0F, 0F);
	    
	    rightFin = new ModelRenderer(this, 0, 0);
	    rightFin.addBox(0F, 0F, -0.5F, 0, 1, 1);
	    rightFin.setRotationPoint(-0.5F, 23F, 0F);
	    rightFin.setTextureSize(textureWidth, textureHeight);
	    rightFin.mirror = true;
	    setRotation(rightFin, 0F, 0F, 0F);
	    
	    tail = new ModelRenderer(this, 0, 8);
	    tail.addBox(0F, -1F, 0F, 0, 2, 3);
	    tail.setRotationPoint(0F, 21.5F, 2.5F);
	    tail.setTextureSize(textureWidth, textureHeight);
	    tail.mirror = true;
	    setRotation(tail, 0F, 0F, 0F);		
	}
	
	@Override
	public void render(Entity entity, float time, float limbSwingDistance, float unknown, float headYRotation, float headXRotation, float yTranslation)
	{
		// child (non-adult) entity scaling
		if (this.isChild)
		{
			float scale = 0.5f;
			GlStateManager.pushMatrix();
			GlStateManager.scale(scale, scale, scale);
			GlStateManager.translate(0, 24.0f * yTranslation, 0);
		}
		
		// apply entity pitch (apparently ignored!)
		FishEntity fishEntity = (FishEntity) entity;
		
		// due to model offset restriction, translates are required to alter rotation point
		GlStateManager.translate(0, 21.5f/16.0f, 0);
		GlStateManager.rotate(fishEntity.rotationPitch, 1f, 0f, 0f);
		GlStateManager.translate(0, -21.5f/16.0f, 0);
		
	    super.render(entity,  time, limbSwingDistance, unknown, headYRotation, headXRotation, yTranslation);
	    setRotationAngles(time, limbSwingDistance, unknown, headYRotation, headXRotation, yTranslation, entity);
	    body.render(yTranslation);
	    dorsalFin.render(yTranslation);
	    leftFin.render(yTranslation);
	    rightFin.render(yTranslation);
	    
	    // tail animation
	    double animTime = System.currentTimeMillis() * 0.001;
		GlStateManager.pushMatrix();
		GlStateManager.rotate(15f * (float)Math.sin(animTime * Math.PI * 2), 0f, 1f, 0f);
	    tail.render(yTranslation);
	    GlStateManager.popMatrix();

		if (this.isChild)
		{
			// reset scaling and translation if it was a child render
			GlStateManager.popMatrix();
		}
	}
		
	private void setRotation(ModelRenderer model, float rotateAngleX, float rotateAngleY, float rotateAngleZ)
	{
		model.rotateAngleX = rotateAngleX;
	    model.rotateAngleY = rotateAngleY;
	    model.rotateAngleZ = rotateAngleZ;
    }

	
	// model components
	private ModelRenderer body;
	private ModelRenderer dorsalFin;
	private ModelRenderer leftFin;
	private ModelRenderer rightFin;
	private ModelRenderer tail;
	
	private static final float degToRad =  (float)Math.PI / 180.0f;
}
