package org.colinvella.fancyfish.item;

import org.colinvella.fancyfish.creativetab.ModCreativeTabs;
import org.colinvella.fancyfish.entity.fish.FishEntity;
import org.colinvella.fancyfish.item.ModItem;
import org.colinvella.fancyfish.item.ModItemRegistry;

import net.minecraft.creativetab.CreativeTabs;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.BlockPos;
import net.minecraft.util.EnumFacing;
import net.minecraft.world.World;

public class CapturedFishItem extends ModItem
{
	public CapturedFishItem(String id, Class<? extends FishEntity> releasedFishEntity)
	{
		super(id, 1, ModCreativeTabs.FancyFishTab);
		
		this.releasedFishEntity = releasedFishEntity;
	}

	// returns the class of the corresponding fish entity that is released on use
	public Class<? extends FishEntity> getReleasedFishEntity()
	{
		return this.releasedFishEntity;
	}
	
	@Override
	public boolean onItemUse(ItemStack itemStack, EntityPlayer entityPlayer, World world, BlockPos pos, EnumFacing side,
			float hitX, float hitY, float hitZ)
	{
		// only run on server side
		if (world.isRemote)
			return true;
				
		Item equippedItem = itemStack.getItem();
		
		// retrieve tag in case fish was originally assigned one
		NBTTagCompound tagCompound = itemStack.getTagCompound();
		String fishEntityTag = tagCompound == null ? null : tagCompound.getString("tag");

		// get class of captured fish entity and create instance by reflection
		Class<? extends FishEntity> fishEntityClass = getReleasedFishEntity();
		FishEntity fishEntity;
		try
		{
			fishEntity = fishEntityClass.getConstructor(World.class).newInstance(world);
		}
		catch (Exception exception)
		{
			logger.error("Unable to spawn fish entity " + fishEntityClass.getSimpleName() + ". Reason: " + exception.getMessage());
			return true;
		}
		
		// restore custom name tag if applicable
		if (fishEntityTag != null)
			fishEntity.setCustomNameTag(fishEntityTag);

		// shift to (empty) block determined by target side
		pos = pos.offset(side);
		
		// set position from hit coordinates and spawn fish
		fishEntity.setPosition(pos.getX() + 0.5, pos.getY() + 0.5, pos.getZ() + 0.5);
		world.spawnEntityInWorld(fishEntity);
				
		logger.debug(fishEntity.getSpecies() + " released from fish bowl");
		
		// replace captured fish item with empty fish bowl item
		entityPlayer.setCurrentItemOrArmor(0, new ItemStack(ModItemRegistry.FishBowl));
		return true;
	}	
	
	private Class<? extends FishEntity> releasedFishEntity;
}
