package org.colinvella.fancyfish.item.combat;

import org.colinvella.fancyfish.FancyFishMod;

import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.potion.Potion;
import net.minecraft.potion.PotionEffect;
import net.minecraft.util.ChatComponentTranslation;
import net.minecraft.world.World;
import net.minecraftforge.common.util.EnumHelper;

public class FishScaleArmorItem extends ModItemArmor
{
	public static final String HELMET_ID = "FishScaleHelmet";
	public static final String CHESTPLATE_ID = "FishScaleChestPlate";
	public static final String LEGGINGS_ID = "FishScaleLeggings";
	public static final String BOOTS_ID = "FishScaleBoots";
	
	public FishScaleArmorItem(String id, int renderIndex, int armorType)
	{
		super(id, Material, renderIndex, armorType);
	}
	
	@Override
	public void onArmorTick(World world, EntityPlayer player, ItemStack itemStack)
	{
		// do default behaviour first
		super.onArmorTick(world, player, itemStack);
		
		// count how many fish scale armor items are worn by the user
		int armorCount = 0;
		for(int i = 0; i < 4; i++)
		{
			ItemStack itemStackArmor = player.getEquipmentInSlot(i + 1);
			if (itemStackArmor == null)
				continue;
			
			Item itemArmor = itemStackArmor.getItem();
			if (itemArmor == null)
				continue;

			if(itemArmor instanceof FishScaleArmorItem)
				armorCount++;
		}

		// apply potion only if wearing full armor set
		if(armorCount == 4)
		    player.addPotionEffect(new PotionEffect(Potion.waterBreathing.id, 20, 1));
		
		// show message when adding or removing armour
		if (!player.worldObj.isRemote && previousArmorCount != armorCount)
		{
			String messageKey = armorCount < 4
					? "item.FishScaleArmor.message.cannotBreathUnderwater"
					: "item.FishScaleArmor.message.canBreathUnderwater"; 
			player.addChatComponentMessage(new ChatComponentTranslation(messageKey));
			previousArmorCount = armorCount;
		}
	};

	private static final int Durability = 20;
	private static final int[] DamageReduction = new int[]{2,6,5,2};
	private static final int Enchantability = 25;

	private static final ArmorMaterial Material = EnumHelper.addArmorMaterial(
			"FishScale", FancyFishMod.MOD_ID + ":FishScaleArmor",
			Durability, DamageReduction, Enchantability);
	
	private static int previousArmorCount = 0;
	

}
