package org.colinvella.fancyfish.tileentity.renderer;

import org.colinvella.fancyfish.FancyFishMod;
import org.colinvella.fancyfish.item.LiveFishItem;
import org.colinvella.fancyfish.tileentity.CapturedFishState;
import org.colinvella.fancyfish.tileentity.FishTankTileEntity;
import org.colinvella.fancyfish.tileentity.model.CapturedFishModel;
import org.colinvella.fancyfish.tileentity.model.CapturedFishModel;

import net.minecraft.client.renderer.GlStateManager;
import net.minecraft.client.renderer.tileentity.TileEntitySpecialRenderer;
import net.minecraft.entity.Entity;
import net.minecraft.item.Item;
import net.minecraft.item.ItemStack;
import net.minecraft.tileentity.TileEntity;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.fml.relauncher.Side;
import net.minecraftforge.fml.relauncher.SideOnly;

@SideOnly(Side.CLIENT)
public class FishTankTileEntityRenderer extends TileEntitySpecialRenderer
{
    private CapturedFishModel capturedFishModel = new CapturedFishModel();
 
    private void renderFishtankTileEntity(FishTankTileEntity fishTankTileEntity,
    	double x, double y, double z, float partialTicks, int unknownInt)
    {
    	int slotCount = fishTankTileEntity.getSizeInventory();

    	CapturedFishState[] capturedFishStates = fishTankTileEntity.getCapturedFishStates();
    	
    	for (int slotIndex = 0; slotIndex < slotCount; slotIndex++)
    	{
    		ItemStack itemStack = fishTankTileEntity.getStackInSlot(slotIndex);
    		if (itemStack == null)
    			continue;
    		
    		Item item = itemStack.getItem();
    		if (!(item instanceof LiveFishItem))
    			continue;
    		
    		CapturedFishState capturedFishState = capturedFishStates[slotIndex];
    		
    		LiveFishItem liveFishItem = (LiveFishItem)item;
    		
            GlStateManager.pushMatrix();
            GlStateManager.translate(x + capturedFishState.posX, y + capturedFishState.posY, z + capturedFishState.posZ);

            GlStateManager.scale(0.5, -0.5, 0.5);
            
            float time = 0;
            float limbSwingDistance = 0;
            float unknown = 0;
            float headYRotation = 0;
            float headXRotation = 0.0f;
            float yTranslation = 0.0625F;
            
            ResourceLocation fishTexture = new ResourceLocation(
            	FancyFishMod.MOD_ID + ":textures/entity/fish/"+liveFishItem.getId().replace("Live", "")+".png");
            
            this.bindTexture(fishTexture);
            GlStateManager.enableCull();
            
            GlStateManager.rotate(-(float)capturedFishState.getYaw(), 0, 1, 0);

            GlStateManager.rotate(-(float)capturedFishState.getPitch(), 1, 0, 0);

            
            this.capturedFishModel.render((Entity)null, time, limbSwingDistance, unknown, headYRotation, headXRotation, yTranslation);
            GlStateManager.popMatrix();
    	}
    }

    public void renderTileEntityAt(TileEntity tileEntity, double posX, double posZ, double p_180535_6_, float p_180535_8_, int p_180535_9_)
    {
        this.renderFishtankTileEntity((FishTankTileEntity)tileEntity, posX, posZ, p_180535_6_, p_180535_8_, p_180535_9_);
    }
}